@@ -6,7 +6,7 @@ import time
 
 class Omxplayer(Player):
     __logger=logging.getLogger(__name__)
-    __cmdline=""
+    __cmdline="-o both"
     __playerline="omxplayer -b"
     __playerstatus=0 # 0 stopped, 1 playing, 2 paused
     __currentfile=""
@@ -14,7 +14,11 @@ class Omxplayer(Player):
     
     keymapping = {
         'pause' : 'p',
-        'quit'  : 'q'
+        'quit'  : 'q',
+        'volume': {
+                    'up'   : '+',
+                    'down' : '-'
+                  }
         }
     
 
@@ -49,6 +53,8 @@ class Omxplayer(Player):
             self.__process.stdin.flush()
             
     def getcmdline(self,file):
+        finished_cmdline = self.__playerline + " " + self.__cmdline + " '" + file + "'"
+        self.__logger.debug('omxplayer cmdline: ' + finished_cmdline)
         return self.__playerline + " " + self.__cmdline + " '" + file + "'"
 
     def play(self, file):
@@ -92,6 +98,18 @@ class Omxplayer(Player):
                 subprocess.Popen(shlex.split("killall omxplayer.bin")).wait() ##quickhack
             self.__resetplayer()
             self.__logger.debug("player stopped")
+            
+    def volumeUp(self):
+        self.poll()
+        self.__logger.debug("increase vol")
+        if(self.__process is not None):
+            self.send(self.keymapping['volume']['up'])
+        
+    def volumeDown(self):
+        self.poll()
+        self.__logger.debug("decrease vol")
+        if(self.__process is not None):
+            self.send(self.keymapping['volume']['down'])
         
     def getDict(self):
         self.poll()
@@ -100,6 +118,4 @@ class Omxplayer(Player):
         tempDict['playerStatus'] = self.__playerstatus
         tempDict['currentFile'] = self.__currentfile
         return tempDict
-        
-
-        
+    
